@@ -2,23 +2,8 @@ package Business::OnlinePayment::Litle::ChargebackActivityResponse;
 use strict;
 use warnings;
 
-=head1 NAME
+# ABSTRACT: Business::OnlinePayment::Litle::ChargebackActivityResponse - Response Objects
 
-Business::OnlinePayment::Litle::ChargebackActivityResponse
-
-=head2 METHODS
-
-Additional methods created by this package.
-
-=over
-
-=item new
-
-Create a new chargeback activity response object.
-
-=back
-
-=cut
 
 sub new{
     my ($class, $args) = @_;
@@ -48,3 +33,50 @@ sub _build_subs {
 }
 
 1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Business::OnlinePayment::Litle::ChargebackActivityResponse - Business::OnlinePayment::Litle::ChargebackActivityResponse - Response Objects
+
+=head1 VERSION
+
+version 0.951
+
+=head1 NAME
+
+Business::OnlinePayment::Litle::ChargebackActivityResponse
+
+=head2 METHODS
+
+Additional methods created by this package.
+
+=over
+
+=item new
+
+Create a new chargeback activity response object.
+
+=back
+
+=head1 AUTHOR
+
+Jason Hall <jayce@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by Jason Hall.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=head1 VERSION
+
+version 0.951
+
+=cut
